@@ -66,6 +66,14 @@ URL_DEVICE_INVERTER_COMMON = {
 }
 
 
+class NotSupportedError(ValueError):
+    """
+    An error to be raised if a specific feature is not supported by the specified device
+    """
+
+    pass
+
+
 class Fronius:
     """
     Interface to communicate with the Fronius Symo over http / JSON
@@ -165,6 +173,7 @@ class Fronius:
         system_meter=True,
         system_inverter=True,
         device_meter=frozenset([0]),
+        # storage is not necessarily supported by every fronius device
         device_storage=frozenset([0]),
         device_inverter=frozenset([1]),
         loop=None,
@@ -213,9 +222,15 @@ class Fronius:
         return sensor_data["status"]["Reason"]
 
     async def _current_data(self, fun, spec, spec_name, *spec_formattings):
-        res = await self._fetch_solar_api(spec, spec_name, *spec_formattings)
-
         sensor = {}
+        try:
+            res = await self._fetch_solar_api(spec, spec_name, *spec_formattings)
+        except ValueError:
+            # except if Host returns 404
+            raise NotSupportedError(
+                "Device type {} not supported by the fronius device".format(spec_name)
+            )
+
         try:
             sensor.update(Fronius._status_data(res))
             # TODO use update here as well
